@@ -331,11 +331,10 @@ class linux_intelligent_ocr_solution():
 		
 	def new(self,*data):
 		if(self.textview.new()):
-			try:
-				file = open("{}/.lios_recent".format(macros.home_dir),"w")
+			self.preferences.starting_page_number = 1
+			with open("{}/.lios_recent".format(macros.home_dir),"w") as file:
 				file.write("")
-			except:
-				pass
+
 	def go_to_page(self,*data):
 		spinbutton_page = widget.SpinButton(0,0,self.preferences.starting_page_number,1,5,0)
 		dlg = dialog.Dialog(_("Go to page"),(_("Go"), dialog.Dialog.BUTTON_ID_1,_("Close!"), dialog.Dialog.BUTTON_ID_2))
@@ -971,9 +970,21 @@ class linux_intelligent_ocr_solution():
 		self.available_ocr_engine_list[self.preferences.ocr_engine].cancel()
 		self.notify_information("Terminated",0.0030)
 		
-	def open_readme(self,widget,data=None):
-		with open(macros.readme_file) as file:
-			self.textview.set_text(file.read())
+	def open_readme(self,*data):
+		if(self.textview.get_modified()):
+			dlg = dialog.Dialog(_("Warning!"),
+			 (_("No"),dialog.Dialog.BUTTON_ID_1,_("Yes"),dialog.Dialog.BUTTON_ID_2))
+			label = widget.Label(_("Current text not saved! do you want to load readme without saving ? "))
+			label.show()
+			dlg.add_widget(label)
+			response = dlg.run()
+			if response == dialog.Dialog.BUTTON_ID_2:
+				with open(macros.readme_file) as file:
+					self.textview.set_text(file.read())
+			dlg.destroy()
+		else:
+			with open(macros.readme_file) as file:
+				self.textview.set_text(file.read())
 
 
 	@on_thread			
@@ -1147,9 +1158,10 @@ class linux_intelligent_ocr_solution():
 		if response == FileChooserDialog.ACCEPT:
 			file_name = dlg.get_filename()
 			command = "convert " 
-			for item in reversed(self.iconview.get_selected_item_names()):
+			for item in self.iconview.get_selected_item_names():
 				command += item + " "
-			command += file_name
+			command += '"'+file_name+'"'
+			print("File name : ",file_name)
 			os.system(command)
 		dlg.destroy()
 
